﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using ThinkGeo.Cloud;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace _9640
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            winformsMap1.MapClick += WinformsMap1_MapClick;

            LayerOverlay layerOverlay = new LayerOverlay();
            InMemoryFeatureLayer pointLayer = new InMemoryFeatureLayer();
            pointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColors.Red, 10);
            pointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            InMemoryFeatureLayer rLayer = new InMemoryFeatureLayer();
            rLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColors.Red, 1, true);
            rLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            layerOverlay.Layers.Add(pointLayer);
            layerOverlay.Layers.Add(rLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            winformsMap1.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
            winformsMap1.Refresh();
        }



        private void WinformsMap1_MapClick(object sender, MapClickWinformsMapEventArgs e)
        {
            InMemoryFeatureLayer pointLayer = (winformsMap1.Overlays[0] as LayerOverlay).Layers[0] as InMemoryFeatureLayer;
            InMemoryFeatureLayer rLayer = (winformsMap1.Overlays[0] as LayerOverlay).Layers[1] as InMemoryFeatureLayer;

            RoutingClient rtgClt = new RoutingClient("key", "key");
            RoutingGetRouteOptions rtgOpts = new RoutingGetRouteOptions();
            ThinkGeo.Cloud.RoutingGetRouteResult result;
            Feature f;

            double plat = 39.842934;
            double plon = -75.2415481;
            double dlat = 39.8444378;
            double dlon = -75.126497;
            PointShape sp = new PointShape(plon, plat);
            PointShape ep = new PointShape(dlon, dlat);

            // Clear pointLayer
            pointLayer.InternalFeatures.Clear();

            // Set route options
            rtgOpts.DistanceUnit = DistanceUnit.Mile;
            rtgOpts.TurnByTurn = true;

            // Run Route
            result = rtgClt.GetRoute(new Collection<PointShape>() { sp, ep }, rtgOpts);

            // Get Route Results
            double rMiles = Math.Round(result.RouteResult.Routes[0].Distance, 2);
            double rTime = result.RouteResult.Routes[0].Duration.TotalMinutes;

            // Add route start point to InMemoryFeatureLayer
            f = new Feature(plon, plat, "Start") { Tag = "Start" };
            f.ColumnValues.Add("Place", "Start");
            pointLayer.InternalFeatures.Add(f);
            // Add route end point to InMemoryFeatureLayer
            f = new Feature(dlon, dlat, "End") { Tag = "End" };
            f.ColumnValues.Add("Place", "End");
            pointLayer.InternalFeatures.Add(f);

            // Get route line shape from result
            LineShape rtLine = result.RouteResult.Routes[0].Shape;

            // Add route line shape to routing layer
            rLayer.InternalFeatures.Add(new Feature(rtLine));


            pointLayer.Open();
            winformsMap1.CurrentExtent = pointLayer.GetBoundingBox();

            winformsMap1.Refresh();
        }


    }
}
